%define major           4.3
%define libname         %mklibname %{name} %{major}
%define libname_devel   %mklibname %{name} -d

%define srcname         CGNS

Name:    cgns
Version: 4.3.0
Release: %mkrel 2
Summary: Computational fluid dynamics notation system
License: zlib
Group:   Sciences/Physics
URL:     https://cgns.github.io
Source0: https://github.com/CGNS/CGNS/archive/%{srcname}-%{version}.tar.gz

Patch1:  cgns-4.3.0-libdir.patch

BuildRequires: cmake
BuildRequires: gcc-gfortran
BuildRequires: hdf5-devel
BuildRequires: hdf5
BuildRequires: pkgconfig(x11)
BuildRequires: tcl
BuildRequires: pkgconfig(tcl)
BuildRequires: pkgconfig(tk)
BuildRequires: pkgconfig(gl)
BuildRequires: pkgconfig(glu)
BuildRequires: pkgconfig(xext)
BuildRequires: pkgconfig(xmu)

%description
The CFD General Notation System (CGNS) provides a general, portable,
and extensible standard for the storage and retrieval of computational
fluid dynamics (CFD) analysis data. It consists of a collection of
conventions, and free and open software implementing those
conventions. It is self-descriptive, machine-independent,
well-documented, and administered by an international steering
committee.

%package -n %{libname}
Summary:        Libraries for CGNS
Group:          System/Libraries

%description -n %{libname}
%{summary}.

%package -n %{libname_devel}
Summary:        Development files for CGNS
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
This package provides the CGNS header and module files required to
compile C and Fortran programs that use CNGS.

%prep
%setup -q -n %{srcname}-%{version}
%autopatch -p1

%build
export FFLAGS="%{optflags} -fPIC"
%cmake                                                              \
        -DCGNS_ENABLE_FORTRAN:BOOL=ON                               \
        -DCGNS_BUILD_CGNSTOOLS:BOOL=ON                              \
	-DCGNS_ENABLE_HDF5:BOOL=ON                                  \
	-DCGNS_BUILD_SHARED:BOOL=ON                                 \
	-DHDF5_NEED_ZLIB:BOOL=ON                                    \
%ifarch x86_64 aarch64
        -DCGNS_ENABLE_64BIT:BOOL=ON
%endif

#cmake_build
%__make V=1 -C build

%install
export QA_RPATHS=0x0001
%cmake_install

# drop static build
rm -rf %{buildroot}%{_libdir}/libcgns.a

%files
%doc README.md license.txt
%{_bindir}/*
%{_datadir}/cgnstools

%files -n %{libname}
%{_libdir}/libcgns.so.%{major}

%files -n %{libname_devel}
%{_includedir}/*
%{_libdir}/libcgns.so
%{_libdir}/cmake/cgns


%changelog
* Mon Dec 05 2022 kekepower <kekepower> 4.3.0-2.mga9
+ Revision: 1918210
- Rebuid for new hdf5-5.12.x

* Fri Aug 26 2022 eatdirt <eatdirt> 4.3.0-1.mga9
+ Revision: 1880556
- Update to version 4.3.0

* Fri Apr 01 2022 umeabot <umeabot> 4.2.0-4.mga9
+ Revision: 1838365
- Mageia 9 Mass Rebuild

* Fri Mar 11 2022 mrambo3501 <mrambo3501> 4.2.0-3.mga9
+ Revision: 1790418
- bump rel
- remove the global rpath disable
- ignore the standard 0x0001 rpath

* Wed Mar 09 2022 mrambo3501 <mrambo3501> 4.2.0-2.mga9
+ Revision: 1790162
- disable rpath checking

* Thu Aug 26 2021 eatdirt <eatdirt> 4.2.0-1.mga9
+ Revision: 1742597
- Upgrade to version 4.2.0

* Wed Oct 14 2020 eatdirt <eatdirt> 4.1.2-1.mga8
+ Revision: 1635845
- Upgrade to version 4.1.2
+ wally <wally>
- drop old obsoletes

* Sun Mar 22 2020 eatdirt <eatdirt> 4.1.1-2.mga8
+ Revision: 1558969
+ rebuild (emptylog)

* Sun Mar 22 2020 eatdirt <eatdirt> 4.1.1-1.mga8
+ Revision: 1558939
- Upgrade to version 4.1.1

* Sat Feb 15 2020 umeabot <umeabot> 3.4.0-2.mga8
+ Revision: 1523566
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Mar 07 2019 eatdirt <eatdirt> 3.4.0-1.mga7
+ Revision: 1372224
- Fix missing BR to hdf5
- Upgrade to vesion 3.4.0

* Thu Nov 08 2018 daviddavid <daviddavid> 3.3.1-4.mga7
+ Revision: 1328910
- rebuild for new hdf5 1.10.4

* Sat Sep 22 2018 umeabot <umeabot> 3.3.1-3.mga7
+ Revision: 1296108
- Mageia 7 Mass Rebuild

* Sun Jun 17 2018 wally <wally> 3.3.1-2.mga7
+ Revision: 1237459
- add patch from Debian to fix build with glibc >= 2.27
- fix lib pkg name
- drop static devel pkg

* Tue Oct 10 2017 eatdirt <eatdirt> 3.3.1-1.mga7
+ Revision: 1170831
- Fix missing require
- imported package cgns

